/// <reference path="./Scripts/jspack-vsdoc.js" />

var Diagram = MindFusion.Diagramming.Diagram;
var DiagramLink = MindFusion.Diagramming.DiagramLink;
var Events = MindFusion.Diagramming.Events;
var ShapeNode = MindFusion.Diagramming.ShapeNode;
var ArrayList = MindFusion.Collections.ArrayList;

var Rect = MindFusion.Drawing.Rect;

var Charting = MindFusion.Charting;
var Controls = Charting.Controls;
var Collections = Charting.Collections;
var Drawing = Charting.Drawing;

var diagram;

document.addEventListener("DOMContentLoaded", function ()
{
	// create a Diagram component that wraps the "diagram" canvas
	diagram = MindFusion.Diagramming.Diagram.create(document.getElementById("diagram"));
	diagram.setBehavior(MindFusion.Diagramming.Behavior.LinkShapes);
	diagram.setLinkHeadShapeSize(2);
	diagram.setBounds(new Rect(0, 0, 2000, 2000));

	// draw a pie when the user creates a node
	diagram.addEventListener(Events.nodeCreated, onNodeCreated);

});

//nodeCreated event handler
function onNodeCreated(sender, args)
{
	var node = args.getNode();
	
	var nBounds = node.getBounds ();
	var topLeftCoord = diagram.docToClient(nBounds.topLeft());
	var bottomRightCoord = diagram.docToClient(nBounds.bottomRight());
	
	var pieChartCanvas = document.createElement('canvas');
	pieChartCanvas.width = bottomRightCoord.x - topLeftCoord.x;
	pieChartCanvas.height = bottomRightCoord.y - topLeftCoord.y;

	//create a temporary Canvas for the pie chart
	//to draw itself upon
	document.body.appendChild(pieChartCanvas);
    createPie(pieChartCanvas);
	var pieImageLocation = pieChartCanvas.toDataURL();
    node.setImageLocation(pieImageLocation);
	document.body.removeChild(pieChartCanvas);
}

//draw a pie chart on the provided canvas
function createPie(pieChartCanvas)
{
	var pieChart = new Controls.PieChart(pieChartCanvas);
	pieChart.startAngle = 45;			
	pieChart.showLegend = false;
	pieChart.title = "Sales";
	pieChart.titleMargin = new Charting.Margins(0, 10, 0, 0);
	pieChart.chartPadding = 3;

	// create sample data
	var values = new Collections.List([20.00, 30.00, 15.00, 40.00]);
	pieChart.series = new Charting.PieSeries(
					values,
					new Collections.List(["20", "30", "15", "40"]),
					null);

	var brushes = new Collections.List(
		[
			new Drawing.Brush("#0455BF"),
			new Drawing.Brush("#033E8C"),
			new Drawing.Brush("#F24405"),
			new Drawing.Brush("#F21905")
		]);

	var seriesBrushes = new Collections.List();
	seriesBrushes.add(brushes);

	var strokes = new Collections.List(
		[
			new Drawing.Brush("#c0c0c0")
		]);

	var seriesStrokes = new Collections.List();
	seriesStrokes.add(strokes);

	pieChart.plot.seriesStyle = new Charting.PerElementSeriesStyle(seriesBrushes, seriesStrokes);
	pieChart.theme.highlightStroke = new Drawing.Brush("#000063");
	pieChart.theme.dataLabelsFontSize = pieChartCanvas.height/20;
	pieChart.theme.dataLabelsBrush = new Drawing.Brush("#FFFFFF");

	pieChart.draw();
}



